@@ -42,6 +42,7 @@ XImage  *Ebu_r128_disp::_ibmodeS = 0;
 XImage  *Ebu_r128_disp::_ibpause = 0;
 XImage  *Ebu_r128_disp::_ibstart = 0;
 XImage  *Ebu_r128_disp::_ibreset = 0;
+XImage  *Ebu_r128_disp::_ibpeak1 = 0;
 
 
 int Ebu_r128_disp::loadimg (X_display *disp, const char *sdir, const char *file, XImage **imag)
@@ -74,7 +75,8 @@ int Ebu_r128_disp::init (X_display *disp, const char *shared)
             || loadimg (disp, shared, "bmodeS.png", &_ibmodeS)
             || loadimg (disp, shared, "bpause.png", &_ibpause)
             || loadimg (disp, shared, "bstart.png", &_ibstart)
-            || loadimg (disp, shared, "breset.png", &_ibreset));
+            || loadimg (disp, shared, "breset.png", &_ibreset)
+            || loadimg (disp, shared, "bpeak1.png", &_ibpeak1));
 } 
 
 
@@ -97,6 +99,7 @@ void Ebu_r128_disp::fini (X_display *disp)
     _ibpause->data = 0;
     _ibstart->data = 0;
     _ibreset->data = 0;
+    _ibpeak1->data = 0;
     XDestroyImage (_ihscale09r);
     XDestroyImage (_ihscale09a);
     XDestroyImage (_ihscale18r);
@@ -114,12 +117,14 @@ void Ebu_r128_disp::fini (X_display *disp)
     XDestroyImage (_ibpause);
     XDestroyImage (_ibstart);
     XDestroyImage (_ibreset);
+    XDestroyImage (_ibpeak1);
 }
 
 
 Ebu_r128_disp::Ebu_r128_disp (X_window *parent, X_callback *callb, int xp, int yp, XftColor *bg) :
     X_window (parent, xp, yp, XS, YS, bg->pixel),
-    _callb (callb)
+    _callb (callb),
+    _count (0)
 {
     int x, y;
 
@@ -130,7 +135,12 @@ Ebu_r128_disp::Ebu_r128_disp (X_window *parent, X_callback *callb, int xp, int y
     _t_range = new X_textip (this, 0, &tstyle1, X1 - 120, Y5, 120, 18, 31);
     _t_range->x_map ();
 
-    x = X1 + 80;
+    x = X1 + 50;
+    y = Y5 - 7;
+    _bpeak1 = new Pbutt1 (this, this, BPEAK1, _ibpeak1, x, y, 32, 24);
+    _bpeak1->x_map();
+
+    x = X1 + 120;
     y = Y0 + 4;
     _bmodeM = new Pbutt1 (this, this, BMODEM, _ibmodeM, x, y, 24, 16);
     _bmodeM->x_map();
@@ -148,8 +158,8 @@ Ebu_r128_disp::Ebu_r128_disp (X_window *parent, X_callback *callb, int xp, int y
     _bscaleFS = new Pbutt1 (this, this, BSCALEFS, _ibscaleFS, x, y + 17, 24, 16); 
     _bscaleFS->x_map();
 
-    x = X1 + 80;
-    y = Y5 - 6;
+    x = X1 + 120;
+    y = Y5 - 7;
     _bpause = new Pbutt1 (this, this, BPAUSE, _ibpause, x, y, 24, 24);
     _bpause->x_map();
     _bpause->set_state (2);
@@ -240,6 +250,24 @@ void Ebu_r128_disp::set_range (float v0, float v1)
 }
 
 
+void Ebu_r128_disp::set_peak (float v)
+{
+    if (v > 1.0f) _bpeak1->set_state (4);
+    else if (_bpeak1->state () < 4)
+    {
+        if (v > 0.891f)
+	{
+	    _count = 10;
+            _bpeak1->set_state (2);
+	}
+	else if (_count && --_count == 0)
+	{
+	    _bpeak1->set_state (0);
+	} 
+    }
+}
+
+
 void Ebu_r128_disp::handle_event (XEvent *E)
 {
     switch (E->type)
@@ -296,6 +324,9 @@ void Ebu_r128_disp::handle_callb (int type, X_window *W, XEvent *E)
 	case BRESET:
 	    _callb->handle_callb (RESET, 0, 0);
 	    break;
+	case BPEAK1:
+	    _bpeak1->set_state (0);
+	    break;
 	}
     }
 }
@@ -305,7 +336,7 @@ void Ebu_r128_disp::expose (XExposeEvent *E)
 {
     if (E->count) return;
     XSetFunction (dpy (), dgc (), GXcopy);
-    XPutImage (dpy (), win (), dgc (), _scale,  0, 0,  0, Y0, IMGS, 10); 
+    XPutImage (dpy (), win (), dgc (), _scale,  0, 0,  0, Y0, IMGS, 12); 
     XPutImage (dpy (), win (), dgc (), _ticks,  0, 0,  0, Y1, IMGS, 8); 
     XPutImage (dpy (), win (), dgc (), _imag0,  0, 0,  0, Y2, IMGS, H2); 
     XPutImage (dpy (), win (), dgc (), _imag0,  0, 0,  0, Y3, IMGS, H3); 
