@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <math.h>
 #include "ebu_r128_proc.h"
+#include "peak_proc.h"
 #include "audiofile.h"
 
 
@@ -32,8 +33,8 @@ static void help (void)
 {
     fprintf (stderr, "\nebur128 %s\n", VERSION);
     fprintf (stderr, "(C) 2010-2011 Fons Adriaensen  <fons@linuxaudio.org>\n");
-    fprintf (stderr, "Measure integrated loudness and loudness range of an\n");
-    fprintf (stderr, "audio file according to EBU recommendation R-128.\n");
+    fprintf (stderr, "Measure integrated loudness, loudness range, and peak level\n");
+    fprintf (stderr, "of an audio file according to EBU recommendation R-128.\n");
     fprintf (stderr, "Usage: ebur128 <options> <input file>.\n");
     fprintf (stderr, "Options:\n");
     fprintf (stderr, "  --help   Display this text.\n");
@@ -91,7 +92,8 @@ static void procoptions (int ac, char *av [])
 int main (int ac, char *av [])
 {
     Audiofile      Ainp;
-    Ebu_r128_proc  Proc;
+    Ebu_r128_proc  R128proc;
+    Peak_proc      Peakproc;
     int            i, k, nm, ns, nchan, bsize;
     float          fsamp, km, ks, v;
     float          *p, *inpb, *data [2];
@@ -138,8 +140,9 @@ int main (int ac, char *av [])
 	data [1] = inpb;
     }
 
-    Proc.init (nchan, fsamp);
-    Proc.integr_start ();
+    R128proc.init (nchan, fsamp);
+    R128proc.integr_start ();
+    Peakproc.init (nchan, fsamp);
     while (true)
     {
 	k = Ainp.read (inpb, bsize);
@@ -153,8 +156,10 @@ int main (int ac, char *av [])
 		data [1][i] = *p++;
 	    }
 	}
-	Proc.process (k, data);
+	R128proc.process (k, data);
+	Peakproc.process (k, data);
     }
+    Peakproc.flush ();
     Ainp.close ();
     if (nchan > 1)
     {
@@ -165,37 +170,39 @@ int main (int ac, char *av [])
 
     if (lufs)
     {
-        printf ("Integrated loudness:   %6.1lf LUFS\n", Proc.integrated ());
-        printf ("Loudness range:        %6.1lf LU\n", Proc.range_max () - Proc.range_min ());
+        printf ("Integrated loudness:   %6.1lf LUFS\n", R128proc.integrated ());
+        printf ("Loudness range:        %6.1lf LU\n", R128proc.range_max () - R128proc.range_min ());
+        printf ("Peak level             %6.1lf dB\n", 20 * log10f (Peakproc.readpeak () + 1e-10f));
 	if (full)
 	{
-            printf ("Integrated threshold:  %6.1lf LUFS\n", Proc.integ_thr ());
-            printf ("Range threshold:       %6.1lf LUFS\n", Proc.range_thr ());
-            printf ("Range min:             %6.1lf LUFS\n", Proc.range_min ());
-            printf ("Range max:             %6.1lf LUFS\n", Proc.range_max ());
-            printf ("Momentary max:         %6.1lf LUFS\n", Proc.maxloudn_M ());
-            printf ("Short term max:        %6.1lf LUFS\n", Proc.maxloudn_S ());
+            printf ("Integrated threshold:  %6.1lf LUFS\n", R128proc.integ_thr ());
+            printf ("Range threshold:       %6.1lf LUFS\n", R128proc.range_thr ());
+            printf ("Range min:             %6.1lf LUFS\n", R128proc.range_min ());
+            printf ("Range max:             %6.1lf LUFS\n", R128proc.range_max ());
+            printf ("Momentary max:         %6.1lf LUFS\n", R128proc.maxloudn_M ());
+            printf ("Short term max:        %6.1lf LUFS\n", R128proc.maxloudn_S ());
 	}
     }
     else
     {
-        printf ("Integrated loudness:   %6.1lf LU\n", Proc.integrated () + 23.0f);
-        printf ("Loudness range:        %6.1lf LU\n", Proc.range_max () - Proc.range_min ());
+        printf ("Integrated loudness:   %6.1lf LU\n", R128proc.integrated () + 23.0f);
+        printf ("Loudness range:        %6.1lf LU\n", R128proc.range_max () - R128proc.range_min ());
+        printf ("Peak level             %6.1lf dB\n", 20 * log10f (Peakproc.readpeak () + 1e-10f));
 	if (full)
 	{
-            printf ("Integrated threshold:  %6.1lf LU\n", Proc.integ_thr () + 23.0f);
-            printf ("Range threshold:       %6.1lf LU\n", Proc.range_thr () + 23.0f);
-            printf ("Range min:             %6.1lf LU\n", Proc.range_min () + 23.0f);
-            printf ("Range max:             %6.1lf LU\n", Proc.range_max () + 23.0f);
-            printf ("Momentary max:         %6.1lf LU\n", Proc.maxloudn_M () + 23.0f);
-            printf ("Short term max:        %6.1lf LU\n", Proc.maxloudn_S () + 23.0f);
+            printf ("Integrated threshold:  %6.1lf LU\n", R128proc.integ_thr () + 23.0f);
+            printf ("Range threshold:       %6.1lf LU\n", R128proc.range_thr () + 23.0f);
+            printf ("Range min:             %6.1lf LU\n", R128proc.range_min () + 23.0f);
+            printf ("Range max:             %6.1lf LU\n", R128proc.range_max () + 23.0f);
+            printf ("Momentary max:         %6.1lf LU\n", R128proc.maxloudn_M () + 23.0f);
+            printf ("Short term max:        %6.1lf LU\n", R128proc.maxloudn_S () + 23.0f);
 	}
     }
 
     if (prob)
     {
-        km = Proc.hist_M_count ();
-        ks = Proc.hist_S_count ();
+        km = R128proc.hist_M_count ();
+        ks = R128proc.hist_S_count ();
 	if ((km < 10) || (ks < 10))
 	{
 	    fprintf (stderr, "Insufficient data for probability file.\n");
@@ -205,8 +212,8 @@ int main (int ac, char *av [])
 	    F = fopen ("ebur128-prob", "w");
 	    if (F)
 	    {
-		hm = Proc.histogram_M ();
-		hs = Proc.histogram_S ();
+		hm = R128proc.histogram_M ();
+		hs = R128proc.histogram_S ();
 		nm = 0;
 		ns = 0;
 		for (i = 0; i <= 750; i++)
